@@ -77,8 +77,8 @@ class AwsCdkConstructLibrary(
         self,
         *,
         lambda_auto_discover: typing.Optional[builtins.bool] = None,
-        lambda_options: typing.Optional[projen.awscdk.LambdaFunctionCommonOptions] = None,
-        catalog: typing.Optional[projen.cdk.Catalog] = None,
+        lambda_options: typing.Optional[typing.Union[projen.awscdk.LambdaFunctionCommonOptions, typing.Dict[str, typing.Any]]] = None,
+        catalog: typing.Optional[typing.Union[projen.cdk.Catalog, typing.Dict[str, typing.Any]]] = None,
         cdk_version: builtins.str,
         cdk_assert: typing.Optional[builtins.bool] = None,
         cdk_assertions: typing.Optional[builtins.bool] = None,
@@ -92,28 +92,28 @@ class AwsCdkConstructLibrary(
         repository_url: builtins.str,
         compat: typing.Optional[builtins.bool] = None,
         compat_ignore: typing.Optional[builtins.str] = None,
-        dotnet: typing.Optional[projen.cdk.JsiiDotNetTarget] = None,
+        dotnet: typing.Optional[typing.Union[projen.cdk.JsiiDotNetTarget, typing.Dict[str, typing.Any]]] = None,
         exclude_typescript: typing.Optional[typing.Sequence[builtins.str]] = None,
-        publish_to_go: typing.Optional[projen.cdk.JsiiGoTarget] = None,
-        publish_to_maven: typing.Optional[projen.cdk.JsiiJavaTarget] = None,
-        publish_to_nuget: typing.Optional[projen.cdk.JsiiDotNetTarget] = None,
-        publish_to_pypi: typing.Optional[projen.cdk.JsiiPythonTarget] = None,
-        python: typing.Optional[projen.cdk.JsiiPythonTarget] = None,
+        publish_to_go: typing.Optional[typing.Union[projen.cdk.JsiiGoTarget, typing.Dict[str, typing.Any]]] = None,
+        publish_to_maven: typing.Optional[typing.Union[projen.cdk.JsiiJavaTarget, typing.Dict[str, typing.Any]]] = None,
+        publish_to_nuget: typing.Optional[typing.Union[projen.cdk.JsiiDotNetTarget, typing.Dict[str, typing.Any]]] = None,
+        publish_to_pypi: typing.Optional[typing.Union[projen.cdk.JsiiPythonTarget, typing.Dict[str, typing.Any]]] = None,
+        python: typing.Optional[typing.Union[projen.cdk.JsiiPythonTarget, typing.Dict[str, typing.Any]]] = None,
         rootdir: typing.Optional[builtins.str] = None,
         disable_tsconfig: typing.Optional[builtins.bool] = None,
         docgen: typing.Optional[builtins.bool] = None,
         docs_directory: typing.Optional[builtins.str] = None,
         entrypoint_types: typing.Optional[builtins.str] = None,
         eslint: typing.Optional[builtins.bool] = None,
-        eslint_options: typing.Optional[projen.javascript.EslintOptions] = None,
+        eslint_options: typing.Optional[typing.Union[projen.javascript.EslintOptions, typing.Dict[str, typing.Any]]] = None,
         libdir: typing.Optional[builtins.str] = None,
         projenrc_ts: typing.Optional[builtins.bool] = None,
-        projenrc_ts_options: typing.Optional[projen.typescript.ProjenrcOptions] = None,
+        projenrc_ts_options: typing.Optional[typing.Union[projen.typescript.ProjenrcOptions, typing.Dict[str, typing.Any]]] = None,
         sample_code: typing.Optional[builtins.bool] = None,
         srcdir: typing.Optional[builtins.str] = None,
         testdir: typing.Optional[builtins.str] = None,
-        tsconfig: typing.Optional[projen.javascript.TypescriptConfigOptions] = None,
-        tsconfig_dev: typing.Optional[projen.javascript.TypescriptConfigOptions] = None,
+        tsconfig: typing.Optional[typing.Union[projen.javascript.TypescriptConfigOptions, typing.Dict[str, typing.Any]]] = None,
+        tsconfig_dev: typing.Optional[typing.Union[projen.javascript.TypescriptConfigOptions, typing.Dict[str, typing.Any]]] = None,
         tsconfig_dev_file: typing.Optional[builtins.str] = None,
         typescript_version: typing.Optional[builtins.str] = None,
         default_release_branch: builtins.str,
@@ -121,27 +121,27 @@ class AwsCdkConstructLibrary(
         auto_approve_projen_upgrades: typing.Optional[builtins.bool] = None,
         auto_approve_upgrades: typing.Optional[builtins.bool] = None,
         build_workflow: typing.Optional[builtins.bool] = None,
-        bundler_options: typing.Optional[projen.javascript.BundlerOptions] = None,
+        bundler_options: typing.Optional[typing.Union[projen.javascript.BundlerOptions, typing.Dict[str, typing.Any]]] = None,
         code_cov: typing.Optional[builtins.bool] = None,
         code_cov_token_secret: typing.Optional[builtins.str] = None,
         copyright_owner: typing.Optional[builtins.str] = None,
         copyright_period: typing.Optional[builtins.str] = None,
         dependabot: typing.Optional[builtins.bool] = None,
-        dependabot_options: typing.Optional[projen.github.DependabotOptions] = None,
+        dependabot_options: typing.Optional[typing.Union[projen.github.DependabotOptions, typing.Dict[str, typing.Any]]] = None,
         deps_upgrade: typing.Optional[builtins.bool] = None,
-        deps_upgrade_options: typing.Optional[projen.javascript.UpgradeDependenciesOptions] = None,
+        deps_upgrade_options: typing.Optional[typing.Union[projen.javascript.UpgradeDependenciesOptions, typing.Dict[str, typing.Any]]] = None,
         gitignore: typing.Optional[typing.Sequence[builtins.str]] = None,
         jest: typing.Optional[builtins.bool] = None,
-        jest_options: typing.Optional[projen.javascript.JestOptions] = None,
+        jest_options: typing.Optional[typing.Union[projen.javascript.JestOptions, typing.Dict[str, typing.Any]]] = None,
         mutable_build: typing.Optional[builtins.bool] = None,
         npmignore: typing.Optional[typing.Sequence[builtins.str]] = None,
         npmignore_enabled: typing.Optional[builtins.bool] = None,
         package: typing.Optional[builtins.bool] = None,
         prettier: typing.Optional[builtins.bool] = None,
-        prettier_options: typing.Optional[projen.javascript.PrettierOptions] = None,
+        prettier_options: typing.Optional[typing.Union[projen.javascript.PrettierOptions, typing.Dict[str, typing.Any]]] = None,
         projen_dev_dependency: typing.Optional[builtins.bool] = None,
         projenrc_js: typing.Optional[builtins.bool] = None,
-        projenrc_js_options: typing.Optional[projen.javascript.ProjenrcOptions] = None,
+        projenrc_js_options: typing.Optional[typing.Union[projen.javascript.ProjenrcOptions, typing.Dict[str, typing.Any]]] = None,
         projen_upgrade_auto_merge: typing.Optional[builtins.bool] = None,
         projen_upgrade_schedule: typing.Optional[typing.Sequence[builtins.str]] = None,
         projen_upgrade_secret: typing.Optional[builtins.str] = None,
@@ -152,22 +152,22 @@ class AwsCdkConstructLibrary(
         release_to_npm: typing.Optional[builtins.bool] = None,
         release_workflow: typing.Optional[builtins.bool] = None,
         workflow_bootstrap_steps: typing.Optional[typing.Sequence[typing.Any]] = None,
-        workflow_git_identity: typing.Optional[projen.github.GitIdentity] = None,
+        workflow_git_identity: typing.Optional[typing.Union[projen.github.GitIdentity, typing.Dict[str, typing.Any]]] = None,
         workflow_node_version: typing.Optional[builtins.str] = None,
-        auto_approve_options: typing.Optional[projen.github.AutoApproveOptions] = None,
-        auto_merge_options: typing.Optional[projen.github.AutoMergeOptions] = None,
+        auto_approve_options: typing.Optional[typing.Union[projen.github.AutoApproveOptions, typing.Dict[str, typing.Any]]] = None,
+        auto_merge_options: typing.Optional[typing.Union[projen.github.AutoMergeOptions, typing.Dict[str, typing.Any]]] = None,
         clobber: typing.Optional[builtins.bool] = None,
         dev_container: typing.Optional[builtins.bool] = None,
         github: typing.Optional[builtins.bool] = None,
-        github_options: typing.Optional[projen.github.GitHubOptions] = None,
+        github_options: typing.Optional[typing.Union[projen.github.GitHubOptions, typing.Dict[str, typing.Any]]] = None,
         gitpod: typing.Optional[builtins.bool] = None,
         mergify: typing.Optional[builtins.bool] = None,
-        mergify_options: typing.Optional[projen.github.MergifyOptions] = None,
+        mergify_options: typing.Optional[typing.Union[projen.github.MergifyOptions, typing.Dict[str, typing.Any]]] = None,
         project_type: typing.Optional[projen.ProjectType] = None,
         projen_token_secret: typing.Optional[builtins.str] = None,
-        readme: typing.Optional[projen.SampleReadmeProps] = None,
+        readme: typing.Optional[typing.Union[projen.SampleReadmeProps, typing.Dict[str, typing.Any]]] = None,
         stale: typing.Optional[builtins.bool] = None,
-        stale_options: typing.Optional[projen.github.StaleOptions] = None,
+        stale_options: typing.Optional[typing.Union[projen.github.StaleOptions, typing.Dict[str, typing.Any]]] = None,
         vscode: typing.Optional[builtins.bool] = None,
         allow_library_dependencies: typing.Optional[builtins.bool] = None,
         author_email: typing.Optional[builtins.str] = None,
@@ -179,7 +179,7 @@ class AwsCdkConstructLibrary(
         bugs_email: typing.Optional[builtins.str] = None,
         bugs_url: typing.Optional[builtins.str] = None,
         bundled_deps: typing.Optional[typing.Sequence[builtins.str]] = None,
-        code_artifact_options: typing.Optional[projen.javascript.CodeArtifactOptions] = None,
+        code_artifact_options: typing.Optional[typing.Union[projen.javascript.CodeArtifactOptions, typing.Dict[str, typing.Any]]] = None,
         deps: typing.Optional[typing.Sequence[builtins.str]] = None,
         description: typing.Optional[builtins.str] = None,
         dev_deps: typing.Optional[typing.Sequence[builtins.str]] = None,
@@ -196,7 +196,7 @@ class AwsCdkConstructLibrary(
         npm_token_secret: typing.Optional[builtins.str] = None,
         package_manager: typing.Optional[projen.javascript.NodePackageManager] = None,
         package_name: typing.Optional[builtins.str] = None,
-        peer_dependency_options: typing.Optional[projen.javascript.PeerDependencyOptions] = None,
+        peer_dependency_options: typing.Optional[typing.Union[projen.javascript.PeerDependencyOptions, typing.Dict[str, typing.Any]]] = None,
         peer_deps: typing.Optional[typing.Sequence[builtins.str]] = None,
         repository: typing.Optional[builtins.str] = None,
         repository_directory: typing.Optional[builtins.str] = None,
@@ -205,11 +205,11 @@ class AwsCdkConstructLibrary(
         jsii_release_version: typing.Optional[builtins.str] = None,
         major_version: typing.Optional[jsii.Number] = None,
         npm_dist_tag: typing.Optional[builtins.str] = None,
-        post_build_steps: typing.Optional[typing.Sequence[projen.github.workflows.JobStep]] = None,
+        post_build_steps: typing.Optional[typing.Sequence[typing.Union[projen.github.workflows.JobStep, typing.Dict[str, typing.Any]]]] = None,
         prerelease: typing.Optional[builtins.str] = None,
         publish_dry_run: typing.Optional[builtins.bool] = None,
         publish_tasks: typing.Optional[builtins.bool] = None,
-        release_branches: typing.Optional[typing.Mapping[builtins.str, projen.release.BranchOptions]] = None,
+        release_branches: typing.Optional[typing.Mapping[builtins.str, typing.Union[projen.release.BranchOptions, typing.Dict[str, typing.Any]]]] = None,
         release_every_commit: typing.Optional[builtins.bool] = None,
         release_failure_issue: typing.Optional[builtins.bool] = None,
         release_failure_issue_label: typing.Optional[builtins.str] = None,
@@ -217,17 +217,17 @@ class AwsCdkConstructLibrary(
         release_tag_prefix: typing.Optional[builtins.str] = None,
         release_trigger: typing.Optional[projen.release.ReleaseTrigger] = None,
         release_workflow_name: typing.Optional[builtins.str] = None,
-        release_workflow_setup_steps: typing.Optional[typing.Sequence[projen.github.workflows.JobStep]] = None,
+        release_workflow_setup_steps: typing.Optional[typing.Sequence[typing.Union[projen.github.workflows.JobStep, typing.Dict[str, typing.Any]]]] = None,
         versionrc_options: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         workflow_container_image: typing.Optional[builtins.str] = None,
         workflow_runs_on: typing.Optional[typing.Sequence[builtins.str]] = None,
         name: builtins.str,
-        logging: typing.Optional[projen.LoggerOptions] = None,
+        logging: typing.Optional[typing.Union[projen.LoggerOptions, typing.Dict[str, typing.Any]]] = None,
         outdir: typing.Optional[builtins.str] = None,
         parent: typing.Optional[projen.Project] = None,
         projen_command: typing.Optional[builtins.str] = None,
         projenrc_json: typing.Optional[builtins.bool] = None,
-        projenrc_json_options: typing.Optional[projen.ProjenrcOptions] = None,
+        projenrc_json_options: typing.Optional[typing.Union[projen.ProjenrcOptions, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param lambda_auto_discover: (experimental) Automatically adds an ``aws_lambda.Function`` for each ``.lambda.ts`` handler in your source tree. If this is disabled, you either need to explicitly call ``aws_lambda.Function.autoDiscover()`` or define a ``new aws_lambda.Function()`` for each handler. Default: true
